==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/CalculatedColumnDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { CalculatedColumnDescription } from "./CalculatedColumnDescription";
/**
 * @hidden
 */
var CalculatedColumnDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(CalculatedColumnDescriptionMetadata, _super);
    function CalculatedColumnDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    CalculatedColumnDescriptionMetadata.b = function (a) {
        if (CalculatedColumnDescriptionMetadata.a == null) {
            CalculatedColumnDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            CalculatedColumnDescriptionMetadata.c(CalculatedColumnDescriptionMetadata.a);
        }
        if (a.g(CalculatedColumnDescriptionMetadata.a)) {
            return;
        }
        a.s(CalculatedColumnDescriptionMetadata.a);
    };
    CalculatedColumnDescriptionMetadata.c = function (a) {
    };
    CalculatedColumnDescriptionMetadata.d = function (a) {
        CalculatedColumnDescriptionMetadata.b(a);
        a.u("CalculatedColumn", function () { return new CalculatedColumnDescription(); });
        a.t("CalculatedColumn", CalculatedColumnDescriptionMetadata.a);
    };
    CalculatedColumnDescriptionMetadata.$t = markType(CalculatedColumnDescriptionMetadata, 'CalculatedColumnDescriptionMetadata');
    CalculatedColumnDescriptionMetadata.a = null;
    return CalculatedColumnDescriptionMetadata;
}(Base));
export { CalculatedColumnDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/CalculatedColumnDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { CalculatedColumnDescription } from "./CalculatedColumnDescription";
/**
 * @hidden
 */
var CalculatedColumnDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(CalculatedColumnDescriptionMetadata, _super);
    function CalculatedColumnDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    CalculatedColumnDescriptionMetadata.b = function (a) {
        if (CalculatedColumnDescriptionMetadata.a == null) {
            CalculatedColumnDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            CalculatedColumnDescriptionMetadata.c(CalculatedColumnDescriptionMetadata.a);
        }
        if (a.j(CalculatedColumnDescriptionMetadata.a)) {
            return;
        }
        a.y(CalculatedColumnDescriptionMetadata.a);
    };
    CalculatedColumnDescriptionMetadata.c = function (a) {
    };
    CalculatedColumnDescriptionMetadata.d = function (a) {
        CalculatedColumnDescriptionMetadata.b(a);
        a.aa("CalculatedColumn", function () { return new CalculatedColumnDescription(); });
        a.z("CalculatedColumn", CalculatedColumnDescriptionMetadata.a);
    };
    CalculatedColumnDescriptionMetadata.$t = markType(CalculatedColumnDescriptionMetadata, 'CalculatedColumnDescriptionMetadata');
    CalculatedColumnDescriptionMetadata.a = null;
    return CalculatedColumnDescriptionMetadata;
}(Base));
export { CalculatedColumnDescriptionMetadata };
